PageArgs<TBloc> class

Holds details about the page for the route

Constructors

PageArgs(ValueKey<String> key, Object? pageScope, Object? arguments, Bloc<TBloc> bloc)
Instantiates a new pageArgs

Properties

arguments → Object?
The startup arguments for the page
final
bloc → Bloc<TBloc>
No need to access this. We only keep a reference to this so we can dispose it on pop
final
hashCode → int
The hash code for this object.
no setterinherited
isInitialized ↔ bool
Whether or not the page is already initialized.
getter/setter pair
key → ValueKey<String>
The key of the page
final
pageScope → Object?
The scope of the page. Store mutable state here that you need to dispose on pop. Prefer immutable state, and prefer not using a scope if you don't need to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited