PageBuilder<TState> class

Builds a page route that will mint pages when the user navigates to them

Constructors

PageBuilder({required Widget builder(BuildContext context), required BlocBuilder<TState> blocBuilder(), BlocEvent? initialEvent, bool onPopPage(Route route, dynamic result, PageArgs pageArgs)?})
Constructs a new page builder

Properties

blocBuilder → BlocBuilder<TState> Function()
Returns a BlocBuilder for the page
final
builder → Widget Function(BuildContext context)
Builds the page
final
hashCode → int
The hash code for this object.
no setterinherited
initialEvent ↔ BlocEvent?
The event to send to the Bloc when the page first loads
getter/setter pair
onPopPage → bool Function(Route route, dynamic result, PageArgs pageArgs)
This gets called when the page is popped. You can use this to clean up
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited